#!/usr/bin/env python

# You can download the font Conducting Paths from: https://www.dafont.com/conducting-paths.font

# author: Pocholo
# date: 5/30/20

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from gimpfu import *

def color_metal_text(customtext, letspacing, linspacing, font, textcolor, backcolor):
		
	#Initiates the temporary state
	pdb.gimp_context_push()
	
	#Create a new image
	img = pdb.gimp_image_new(1, 1, RGB_IMAGE)
		
	#Create the text with letter spacing, line spacing and justification
	pdb.gimp_context_set_foreground(textcolor)
	layer = pdb.gimp_text_fontname(img, None, 0, 0, customtext, 100, 
										TRUE, 350, PIXELS, font)
	pdb.gimp_text_layer_set_letter_spacing(layer, letspacing)
	pdb.gimp_text_layer_set_line_spacing(layer, linspacing)
	pdb.gimp_text_layer_set_justification(layer, 2)
		
	#Resize text
	img.resize(layer.width, layer.height, 0, 0)
	
	pdb.gimp_display_new(img)
	
	#Create background
	backlayer = pdb.gimp_layer_new(img, layer.width, layer.height, RGB_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
	pdb.gimp_image_add_layer(img, backlayer, 10)
	pdb.gimp_context_set_background((0, 17, 22))
	pdb.gimp_drawable_fill(backlayer, FILL_BACKGROUND)
	
	#Bump the text
	pdb.plug_in_antialias(img, layer)
	pdb.gimp_image_select_item(img, 2, layer)
	pdb.plug_in_sel2path(img, layer)
	vectors = pdb.gimp_image_get_active_vectors(img)
	pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
	pdb.gimp_selection_feather(img, 15)
	channel = pdb.gimp_selection_save(img)
	pdb.gimp_selection_none(img)
			
	#Add a new gradient layer and apply gradient 1
	pdb.gimp_image_select_item(img, 2, layer)
	gradlayer1 = pdb.gimp_layer_new(img, layer.width, layer.height, RGB_IMAGE, "Colors1", 100, LAYER_MODE_OVERLAY)
	pdb.gimp_image_add_layer(img, gradlayer1, 0)
	pdb.gimp_layer_add_alpha(gradlayer1)
	pdb.gimp_drawable_fill(gradlayer1, FILL_TRANSPARENT)
	pdb.gimp_context_set_gradient("Full saturation spectrum CCW")
	pdb.gimp_drawable_edit_gradient_fill(gradlayer1, 0, 0, TRUE, 3, 0.20, TRUE, 0, 0, layer.width, 0)
	
	img.resize(layer.width, layer.height, 0, 0)
	
	#Add a new gradient layer and apply gradient 2
	gradlayer2 = pdb.gimp_layer_new(img, layer.width, layer.height, RGB_IMAGE, "Colors2", 100, LAYER_MODE_DIFFERENCE)
	pdb.gimp_image_add_layer(img, gradlayer2, 0)
	pdb.gimp_layer_add_alpha(gradlayer2)
	pdb.gimp_drawable_fill(gradlayer2, FILL_TRANSPARENT)
	pdb.gimp_context_set_gradient("Full saturation spectrum CW")
	pdb.gimp_drawable_edit_gradient_fill(gradlayer2, 0, 0, TRUE, 3, 0.20, TRUE, 0, 0, layer.width, 0)
	pdb.gimp_drawable_hue_saturation(gradlayer2, 0, 50, 80, 100, 0)
	pdb.gimp_selection_none(img)
	
	img.resize(layer.width, layer.height, 0, 0)
	
	#Create a duplicate and change the color a little
	non_empty = pdb.gimp_edit_copy(gradlayer2)
	metallayer = pdb.gimp_layer_new(img, layer.width, layer.height, RGB_IMAGE, "Metal look", 100, LAYER_MODE_LINEAR_BURN)
	pdb.gimp_image_add_layer(img, metallayer, 0)
	pdb.gimp_layer_add_alpha(metallayer)
	pdb.gimp_drawable_fill(metallayer, FILL_TRANSPARENT)
	floating_sel = pdb.gimp_edit_paste(metallayer, FALSE)
	pdb.gimp_floating_sel_anchor(floating_sel)
	
	pdb.gimp_levels(metallayer, HISTOGRAM_VALUE, 60, 125, 0.40, 0, 255)
	
	#Bevel and emboss
	pdb.python_layerfx_bevel_emboss(img, metallayer, 
												  1,   #style inner bevel
												 65,   #depth 
												  0,   #direction 
												 14,   #size 
												  5,   #soften
												120,   #angle 
												 20,   #altitude 
												  3,   #gloss_contour- cove deep 
										    "White",   #highlight_color 
												  4,   #highlight_mode - screen
												 40,   #highlight_opacity
										    "Black",   #shadow_color 
												  3,   #shadow_mode - multyply
											 	 75,   #shadow_opacity 
												  1,   #surface_contour- cone 
											  FALSE,   #use_texture 
										 "3D Green",   #pattern 
											    100,   #scale 
											    100,   #tex_depth 
											   TRUE,   #invert 
											  FALSE)   #merge
	
	#Resets the previous user defaults
	pdb.gimp_context_pop()	
	
register(
	"color_metal_text",
	"Creates a coloring riveted text",
	"Creates a coloring riveted text",
	"Pocholo",
	"Pocholo",
	"2020",
	"Color metal text",
	"",
[
	(PF_TEXT, "customtext", "Text string", 'METAL\nRIVETED'),
	(PF_ADJUSTMENT, "Letspacing", "Letter Spacing", 20, (10, 50, 1, 5, 0, 0)),
    (PF_ADJUSTMENT, "linspacing", "Line Spacing", 20, (10, 50, 1, 5, 0, 0)),
	(PF_FONT, "font", "Font face", "ConductingPaths"),
	(PF_COLOR, "textcolor", "Text color", "White"),
	(PF_COLOR, "backcolor", "Background color", (0, 17, 22)),
],
[],
color_metal_text, menu="<Image>/Pocholo-scripts/Color metal text")
main()		